Error codes related to project config validations are deprecated since the
quota controller methods do not perform these validations. Instead services
have to call the Check method, without quota_properties field, to perform
these validations before calling the quota controller methods. These
methods check only for project deletion to be wipe out compliant.
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.