#[non_exhaustive]pub enum Importance {
Low,
High,
UnknownValue(UnknownValue),
}Expand description
Defines the importance of the data contained in the operation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Low
Allows data caching, batching, and aggregation. It provides higher performance with higher data loss risk.
High
Disables data aggregation to minimize data loss. It is for operations that contains significant monetary value or audit trail. This feature only applies to the client libraries.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Importance::value or Importance::name.
Implementations